.. image:: seonu/_static/github_header.png
    :alt: github header
    :align: center

Wísdómhord is a flat file database tool for internal project use.

The main goal of Wísdómhord is to create a flat file db format that produces
files that are in line with my aesthetics, are easy to read and make sense to
check into Github.

.. image:: http://scieldas.autophagy.io/rtd/wisdomhord.png
    :target: http://wisdomhord.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: http://scieldas.autophagy.io/travis/Autophagy/wisdomhord.png
    :target: https://travis-ci.org/Autophagy/wisdomhord
    :alt: Build Status

.. image:: http://scieldas.autophagy.io/licenses/MIT.png
   :target: LICENSE
   :alt: MIT License
